# driada
Dimensionality Reduction for Integrated Activity Data


Installation (old): <br>
`conda create driada` <br>
`conda activate driada` <br>
`conda install pytorch torchvision torchaudio pytorch-cuda=11.8 -c pytorch -c nvidia` <br>
`conda install scikit-learn numba pywavelets networkx pandas regex openpyxl chardet pytest pynndescent seaborn` <br>
`pip install cmake PyDrive2 wget gdown umap-learn pydiffmap cvxpy torch torch-mist`

Installation (new): <br>
`pip install driada[gpu]`